package de.blitzkasse.mobilegastrolite.fiskal.tse.modul;

import java.io.File;
import java.util.Date;
import java.util.Vector;

import android.annotation.SuppressLint;

import com.google.gson.Gson;

import de.blitzkasse.mobilegastrolite.bean.PaidOrders;
import de.blitzkasse.mobilegastrolite.bean.SoldProduct;
import de.blitzkasse.mobilegastrolite.config.Config;
import de.blitzkasse.mobilegastrolite.config.Constants;
import de.blitzkasse.mobilegastrolite.fiskal.tse.bean.TSEInit;
import de.blitzkasse.mobilegastrolite.fiskal.tse.bean.TSEStatus;
import de.blitzkasse.mobilegastrolite.fiskal.tse.bean.TSETransactionRequest;
import de.blitzkasse.mobilegastrolite.fiskal.tse.bean.TSETransactionResult;
import de.blitzkasse.mobilegastrolite.modul.CommunicateModul;
import de.blitzkasse.mobilegastrolite.util.DevicesUtil;
import de.blitzkasse.mobilegastrolite.util.FileUtil;
import de.blitzkasse.mobilegastrolite.util.HttpURLConnectionUtils;
import de.blitzkasse.mobilegastrolite.util.StringsUtil;

@SuppressLint("NewApi")
public class TSETransactionModul {
	private static final String LOG_TAG = "TSETransactionModul";
	private static final boolean PRINT_LOG = false;
	
	public static final String TseSeparator = "^";
	public static final String TseTaxSeparator = "_";
	public static final int MIN_TSE_INIT_STRING_LENGTH = 37; 
	
	
	public static TSEStatus initTSE(String ipAdress, int ipPort) {
		
		/* send jsoon to server */
		String tseServerURL = "http://" + ipAdress + ":" + ipPort + "/tseInit";
		TSEStatus timStatusResponse = null;
		TSEInit TSEInitBean = makeTSEInitBeanFromFile();
		String jsonInString = (new Gson()).toJson(TSEInitBean);
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(tseServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
		/* JSON to Java object, read it from a Json String. */
		String responseJsonInString = httpURLConnection.getResponseContent();
		if (PRINT_LOG) CommunicateModul.appendToLog(responseJsonInString, LOG_TAG);
		responseJsonInString = responseJsonInString.replace("null{", "{");
		timStatusResponse = (new Gson()).fromJson(responseJsonInString, TSEStatus.class);
		} catch (Exception e) {
			if (PRINT_LOG) CommunicateModul.appendToLog(e.toString(), LOG_TAG);
		}
		return (timStatusResponse);
	}	
	
	
	public static TSEStatus getTSEStatus(String ipAdress, int ipPort) {
		
		/* send jsoon to server */
		String tseServerURL = "http://" + ipAdress + ":" + ipPort + "/tseStatus";
		TSEStatus timStatusResponse = null;
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(tseServerURL, "");
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_GET);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
		/* JSON to Java object, read it from a Json String. */
		String responseJsonInString = httpURLConnection.getResponseContent();
		if (PRINT_LOG) CommunicateModul.appendToLog(responseJsonInString, LOG_TAG);
		responseJsonInString = responseJsonInString.replace("null{", "{");
		timStatusResponse = (new Gson()).fromJson(responseJsonInString, TSEStatus.class);
		} catch (Exception e) {
			if (PRINT_LOG) CommunicateModul.appendToLog(e.toString(), LOG_TAG);
		}
		return (timStatusResponse);
	}		
	
	
	public static TSETransactionResult TSETransaction(Vector <SoldProduct> soldProductList, String paymentType, String ipAdress, int ipPort) {
		
		/* send jsoon to server */
		String tseServerURL = "http://" + ipAdress + ":" + ipPort + "/tseExecuteTransaction";
		TSETransactionRequest tseTransactionRequest = makeTSETransactionRequest(soldProductList, paymentType);
		String jsonInString = (new Gson()).toJson(tseTransactionRequest);
		if (PRINT_LOG) CommunicateModul.appendToLog(jsonInString, LOG_TAG);
		
		TSETransactionResult tseTransactionResponse = null;
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(tseServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
		/* JSON to Java object, read it from a Json String. */
		String responseJsonInString = httpURLConnection.getResponseContent();
		if (PRINT_LOG) CommunicateModul.appendToLog(responseJsonInString, LOG_TAG);
		responseJsonInString = responseJsonInString.replace("null{", "{");
		tseTransactionResponse = (new Gson()).fromJson(responseJsonInString, TSETransactionResult.class);
		tseTransactionResponse.setProcessData(tseTransactionRequest.getProcessData());
		} catch (Exception e) {
			if (PRINT_LOG) CommunicateModul.appendToLog(e.toString(), LOG_TAG);
		}
		return (tseTransactionResponse);
	}		
	
	
	
	public static TSETransactionRequest makeTSETransactionRequest(Vector <SoldProduct> soldProductList, String paymentType) {
		TSETransactionRequest requestObject = new TSETransactionRequest();	
		
		if ((paymentType != null) && paymentType.equals(PaidOrders.PAYMENT_MODE_CASCH)) {
			paymentType = "Bar";
		} else {
			paymentType = "Unbar";
		}
		
		String receiptData = "Beleg" + TseSeparator; 
        float turnover19_16 = 0;
        float turnover07_05 = 0;
        float turnover1007 = 0;
        float turnover505 = 0;
        float turnover000 = 0;	
        float totalSumm = 0;
		for (SoldProduct product : soldProductList) {
			if (product == null) continue;
			float totalItemPrice = (float)(product.getProductPrice() * product.getProductCount());
	        turnover19_16 += ((product.getProductTax() == 19f) || ((product.getProductTax() == 16f))) ? totalItemPrice : 0;
	        turnover07_05 += ((product.getProductTax() == 7f) || ((product.getProductTax() == 5f))) ? totalItemPrice : 0;
	        turnover1007 += (product.getProductTax() == 10.7f) ? totalItemPrice : 0;
	        turnover505 += (product.getProductTax() == 5.5f) ? totalItemPrice : 0;
	        turnover000 += (product.getProductTax() == 0f) ? totalItemPrice : 0;	
	        totalSumm += totalItemPrice;
	    }
		receiptData += StringsUtil.formatString(Config.FLOAT_FORMAT_SIMPLE, turnover19_16) + TseTaxSeparator;
		receiptData +=  StringsUtil.formatString(Config.FLOAT_FORMAT_SIMPLE, turnover07_05) + TseTaxSeparator; 
		receiptData +=  StringsUtil.formatString(Config.FLOAT_FORMAT_SIMPLE, turnover1007) + TseTaxSeparator;
		receiptData += StringsUtil.formatString(Config.FLOAT_FORMAT_SIMPLE, turnover505) + TseTaxSeparator;
		receiptData += StringsUtil.formatString(Config.FLOAT_FORMAT_SIMPLE, turnover000) + TseSeparator;
		receiptData += StringsUtil.formatString(Config.FLOAT_FORMAT_SIMPLE, totalSumm) + ":" + paymentType;
		receiptData = receiptData.replace(",", ".");
		
		TSEInit tseInit = makeTSEInitBeanFromFile ();
		requestObject.setClientId(tseInit.getClientId());
		requestObject.setProcessData(receiptData);
		/* Timestamp withot Timezoone */
		requestObject.setTransactionDate((new Date()).getTime());
		
		return requestObject;
	}
	
	public static TSEInit makeTSEInitBeanFromFile () {
		TSEInit tseInitBean = new TSEInit();
		
		/* create dir */ 
		String dirName = Constants.BASE_DIR_PATH  + Constants.TSE_DIR;
		File dir = new File( dirName);
		if (!dir.isDirectory()) dir.mkdirs();
		dir.setWritable(true);
		
		String filePath = dirName + File.separator + Constants.TSE_FILE_NAME;
		/* read from Config or from file */
		String fileContent = Config.TSE_INIT_STRING;
		if ((fileContent == null) || fileContent.trim().equals("")) { 
			fileContent = FileUtil.readFileAsString(filePath);
		}
		
		if ((fileContent == null) || fileContent.trim().equals("")) return tseInitBean;
		fileContent = fileContent.trim();
		if (fileContent.length() < MIN_TSE_INIT_STRING_LENGTH) return tseInitBean;
		try {
			String adminPinStr = fileContent.substring(0, 8);
			String adminPukStr = fileContent.substring(8, 18);
			String timeAdminPinStr = fileContent.substring(18, 26);
			String timeAdminPukStr = fileContent.substring(26, 36);
			String tseCassenName =  fileContent.substring(36);
			
			tseInitBean.setAdminPin(adminPinStr.getBytes("ASCII"));
			tseInitBean.setAdminPuk(adminPukStr.getBytes("ASCII"));
			tseInitBean.setTimeAdminPin(timeAdminPinStr.getBytes("ASCII"));
			tseInitBean.setTimeAdminPuk(timeAdminPukStr.getBytes("ASCII"));
			tseInitBean.setClientId(tseCassenName);
		} catch (Exception e) {}

		return tseInitBean;
	}
	
	
}
