package de.blitzkasse.mobilegastrolite.util;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.net.HttpURLConnection;
import java.net.URL;

import javax.net.ssl.HttpsURLConnection;

import org.apache.http.protocol.HTTP;

import android.os.AsyncTask;
import de.blitzkasse.mobilegastrolite.modul.CommunicateModul;

public class HttpURLConnectionUtils extends Thread {
	private static final String LOG_TAG = "HttpURLConnectionUtils";
	private static final boolean PRINT_LOG = false;
	
	public static String REQUEST_METHOD_POST = "POST";
	public static String REQUEST_METHOD_GET = "GET";
	
	private String scriptURL = null;
	private String parameter = "";
	private volatile String responseContent = "";
	private String contentType = "";
	private String requestMethod = "POST";
	private volatile boolean responseContentFlag = false; 
	
	
	
	public HttpURLConnectionUtils() {
		this.responseContent = null;
		this.responseContentFlag = false;
	} 
	
	public HttpURLConnectionUtils(String scriptURL, String parameter) {
		this.scriptURL = scriptURL;
		this.parameter = parameter;
		this.responseContent = null;
		this.responseContentFlag = false;
	}
	

	private boolean postData(String scriptURL, String parameter) {
	    try {
	    	if (PRINT_LOG) CommunicateModul.appendToLog("scriptURL=" + scriptURL, LOG_TAG);
	    	URL url = new URL(scriptURL);
	    	HttpURLConnection conn = (HttpURLConnection) url.openConnection();
	    	conn.setReadTimeout(5000);
	    	conn.setConnectTimeout(5000);
	    	conn.setDoInput(true);
	    	conn.setDoOutput(true);
	    	conn.setUseCaches(false);
	    	conn.setAllowUserInteraction(false);
	    	conn.setRequestMethod(this.requestMethod);
	    	if (!this.contentType.equals("")) conn.setRequestProperty("Content-Type", this.contentType);

	    	/* send request*/
	    	if ((this.parameter != null) && !this.parameter.equals("")) {
		    	OutputStream requestStream = conn.getOutputStream();
		    	BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(requestStream, "UTF-8"));
		    	writer.write(this.parameter);
		    	writer.flush();
		    	writer.close();
		    	requestStream.close();
		    	conn.connect();
	    	} else {
	    		conn.setDoOutput(false);
	    	}
	    	
	    	/* response */
	        int responseCode = conn.getResponseCode();
	        if (PRINT_LOG) CommunicateModul.appendToLog("responseCode=" + responseCode, LOG_TAG);
	        if (responseCode == HttpsURLConnection.HTTP_OK) {
	        	String line;
	            BufferedReader reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
	            while ((line = reader.readLine()) != null) this.responseContent += line;
	            reader.close();
	            if (PRINT_LOG) CommunicateModul.appendToLog("responseContent=" + this.responseContent, LOG_TAG);
	        }
	    } catch (Exception e) {
	    	if (PRINT_LOG) CommunicateModul.appendToLog(e.getMessage(), LOG_TAG);
	    }
	    this.responseContentFlag = true;
	    return this.responseContentFlag;
	}


	@Override
	public void run() {
		postData(this.scriptURL, this.parameter);
	}

	/**
	 * @return the scriptURL
	 */
	public String getScriptURL() {
		return scriptURL;
	}

	/**
	 * @param scriptURL the scriptURL to set
	 */
	public void setScriptURL(String scriptURL) {
		this.scriptURL = scriptURL;
	}

	/**
	 * @return the parameter
	 */
	public String getParameter() {
		return parameter;
	}

	/**
	 * @param parameter the parameter to set
	 */
	public void setParameter(String parameter) {
		this.parameter = parameter;
	}

	public String getRequestMethod() {
		return requestMethod;
	}

	public void setRequestMethod(String requestMethod) {
		this.requestMethod = requestMethod;
	}
	
	public String getContentType() {
		return contentType;
	}

	public void setContentType(String contentType) {
		this.contentType = contentType;
	}

	/**
	 * @return the responseContent
	 */
	public String getResponseContent() {
		return this.responseContent;
	}

	/**
	 * @return the responseContentFlag
	 */
	public boolean isResponseContentFlag() {
		return this.responseContentFlag;
	}

	
	
	
	
}
