package de.blitzkassewinmac.rest.converter;

import java.util.Date;
import java.util.List;
import java.util.Vector;

import de.blitzkassewinmac.bean.Area;
import de.blitzkassewinmac.bean.BarcodeFormat;
import de.blitzkassewinmac.bean.BarcodeFormatField;
import de.blitzkassewinmac.bean.Categorie;
import de.blitzkassewinmac.bean.CompositeOrderItem;
import de.blitzkassewinmac.bean.Customer;
import de.blitzkassewinmac.bean.PaidOrders;
import de.blitzkassewinmac.bean.ParkingSession;
import de.blitzkassewinmac.bean.PrinterDriver;
import de.blitzkassewinmac.bean.Product;
import de.blitzkassewinmac.bean.ProductAddition;
import de.blitzkassewinmac.bean.ProductSupplement;
import de.blitzkassewinmac.bean.SettingsParameter;
import de.blitzkassewinmac.bean.SoldProduct;
import de.blitzkassewinmac.bean.Tax;
import de.blitzkassewinmac.bean.User;
import de.blitzkassewinmac.modul.ProductAdditionsModul;
import de.blitzkassewinmac.rest.bean.AdditionWrapper;
import de.blitzkassewinmac.rest.bean.AreaWrapper;
import de.blitzkassewinmac.rest.bean.BarcodeFormatFieldsWrapper;
import de.blitzkassewinmac.rest.bean.BarcodeFormatWrapper;
import de.blitzkassewinmac.rest.bean.CategorieWrapper;
import de.blitzkassewinmac.rest.bean.CompositeOrderWrapper;
import de.blitzkassewinmac.rest.bean.ConfigWrapper;
import de.blitzkassewinmac.rest.bean.CustomerWrapper;
import de.blitzkassewinmac.rest.bean.LastPaidOrderWrapper;
import de.blitzkassewinmac.rest.bean.LevelDetailWrapper;
import de.blitzkassewinmac.rest.bean.PaidOrdersWrapper;
import de.blitzkassewinmac.rest.bean.PrinterDriverWrapper;
import de.blitzkassewinmac.rest.bean.ProductWrapper;
import de.blitzkassewinmac.rest.bean.ReturnedOrderItemWrapper;
import de.blitzkassewinmac.rest.bean.SoldProductWrapper;
import de.blitzkassewinmac.rest.bean.SupplementWrapper;
import de.blitzkassewinmac.rest.bean.TaxWrapper;
import de.blitzkassewinmac.rest.bean.UserWrapper;
import de.blitzkassewinmac.util.DateUtils;
import de.blitzkassewinmac.util.StringsUtil;

public class RESTWrapperBeansConverter {

	private static final String LOG_TAG = "RESTWrapperBeansConverter";
	private static final boolean PRINT_LOG = false;

	/**
	 * Convert List of UserWrapper to Vector of User
	 * @param userWrapperList
	 * @return Vector of User
	 */
	public static Vector <Area> convertAreaWrapperListToAreaList (List <AreaWrapper> areaWrapperList ) {
		if (areaWrapperList.size() == 0) return null;
		Vector <Area> areaList = new Vector <Area>();
		for (int i = 0; i < areaWrapperList.size(); i++) {
			AreaWrapper areaWrapperItem =  (AreaWrapper) areaWrapperList.get(i);
			if (areaWrapperItem == null) continue;
			Area item = convertAreaWrapperToArea(areaWrapperItem);
			if (item == null) continue;
			areaList.add(item);
		}
		return areaList;
	}
	
	/**
	 * Convert UserWrapper to User
	 * @param userWrapper
	 * @return User
	 */
	public static Area convertAreaWrapperToArea (AreaWrapper areaWrapper) {
		Area area = new Area();
		area.setAreaId(areaWrapper.getAreaId());
		String areaName = StringsUtil.replaceSpicialChars(areaWrapper.getAreaName());
		area.setAreaName(areaName);
		area.setAreaMode(areaWrapper.getAreaMode());
		return area;
	}

	
	/**
	 * Convert List of UserWrapper to Vector of User
	 * @param userWrapperList
	 * @return Vector of User
	 */
	public static Vector <User> convertUserWrapperListToUserList (List <UserWrapper> userWrapperList ) {
		if (userWrapperList.size() == 0) return null;
		Vector <User> userList = new Vector <User>();
		for (int i = 0; i < userWrapperList.size(); i++) {
			UserWrapper userWrapperItem =  (UserWrapper) userWrapperList.get(i);
			if (userWrapperItem == null) continue;
			User item = convertUserWrapperToUser(userWrapperItem);
			if (item == null) continue;
			userList.add(item);
		}
		return userList;
	}
	
	/**
	 * Convert UserWrapper to User
	 * @param userWrapper
	 * @return User
	 */
	public static User convertUserWrapperToUser (UserWrapper userWrapper) {
		User user = new User();
		user.setId(userWrapper.getId());
		user.setPassword(userWrapper.getPassword());
		String loginName = StringsUtil.replaceSpicialChars(userWrapper.getLogin());
		user.setLogin(loginName);
		user.setName(userWrapper.getName());
		user.setAktiv(userWrapper.isActive());
		user.setStatus(userWrapper.getStatus());
		user.setUserSettings(userWrapper.getSettings());
		return user;
	}	
	
	/***
	 * Convert List of LevelDetailWrapper to Vector of LevelDetail
	 * @param levelDetailWrapperList
	 * @return Vector of ParkingSession  
	 */
	public static Vector <ParkingSession> convertLevelDetailWrapperListToParkingSessionList (List <LevelDetailWrapper> levelDetailWrapperList ) {
		if (levelDetailWrapperList.size() == 0) return null;
		Vector <ParkingSession> levelDetailList = new Vector <ParkingSession>();
		for (int i = 0; i < levelDetailWrapperList.size(); i++) {
			LevelDetailWrapper levelDetailWrapperItem =  (LevelDetailWrapper) levelDetailWrapperList.get(i);
			if (levelDetailWrapperItem == null) continue;
			ParkingSession item = convertLevelDetailWrapperToParkingSession(levelDetailWrapperItem);
			if (item == null) continue;
			levelDetailList.add(item);
		}
		return levelDetailList;
	}
	
	/**
	 * Convert LevelDetailWrapper to ParkingSession
	 * @param levelDetailWrapper
	 * @return ParkingSession
	 */
	public static ParkingSession convertLevelDetailWrapperToParkingSession (LevelDetailWrapper levelDetailWrapper) {
		ParkingSession parkingSession = new ParkingSession ();
		parkingSession.setParkingSessionId(0 + levelDetailWrapper.getId());
		parkingSession.setParkingSessionName("" + levelDetailWrapper.getName());
	    return parkingSession;
	}
	
	/**
	 * Convert ParkingSession to Wrapper
	 * @param aktivLevelDetail
	 * @return LevelDetailWrapper
	 */
	public static LevelDetailWrapper convertParkingSessionToLevelDetailWrapper (ParkingSession aktivLevelDetail) {
		LevelDetailWrapper levelDetailWrapper = new LevelDetailWrapper ();
		levelDetailWrapper.setId(0 + aktivLevelDetail.getParkingSessionId());
		levelDetailWrapper.setName("" + aktivLevelDetail.getParkingSessionName());
		levelDetailWrapper.setDescription(aktivLevelDetail.getParkingSessionName());
	    return levelDetailWrapper;
	}
	
	/***
	 * convert List of CategorieWrapper to Vector of Categorie
	 * @param categorieWrapperList
	 * @return categorieList
	 */
	public static Vector <Categorie> convertCategorieWrapperListToCategorieList (List <CategorieWrapper> categorieWrapperList ) {
		if (categorieWrapperList.size() == 0) return null;
		Vector <Categorie> categorieList = new Vector <Categorie>();
		for (int i = 0; i < categorieWrapperList.size(); i++) {
			CategorieWrapper categorieWrapperItem =  (CategorieWrapper) categorieWrapperList.get(i);
			if (categorieWrapperItem == null) continue;
			Categorie item = convertCategorieWrapperToCategorie(categorieWrapperItem);
			if (item == null) continue;
			categorieList.add(item);
		}
		return categorieList;
	}
	
	/**
	 * convert CategorieWrapper to Categorie 
	 * @param categorieWrapper
	 * @return
	 */
	public static Categorie convertCategorieWrapperToCategorie (CategorieWrapper categorieWrapper) {
		Categorie categorie = new Categorie ();
		categorie.setCategorieId(categorieWrapper.getId());
		categorie.setCategorieMode(categorieWrapper.getMode());
		String name = StringsUtil.replaceSpicialChars(categorieWrapper.getName());
		categorie.setCategorieName(name);
		categorie.setCategorieColor(categorieWrapper.getColor());
		categorie.setCategorieSortIndex(categorieWrapper.getSortId());
		categorie.setNotPrintSaldo(categorieWrapper.isNoOrderPrint());
	    return categorie;
	}
	
	
	/***
	 * convert List of TaxWrapper to Vector of Tax
	 * @param taxWrapperList
	 * @return taxList
	 */
	public static Vector <Tax> convertTaxWrapperListToTaxList (List <TaxWrapper> taxWrapperList ) {
		if (taxWrapperList.size() == 0) return null;
		Vector <Tax> taxList = new Vector <Tax>();
		for (int i = 0; i < taxWrapperList.size(); i++) {
			TaxWrapper taxWrapperItem =  (TaxWrapper) taxWrapperList.get(i);
			if (taxWrapperItem == null) continue;
			Tax item = convertTaxWrapperToTax(taxWrapperItem);
			if (item == null) continue;
			taxList.add(item);
		}
		return taxList;
	}
	
	/**
	 * convert CategorieWrapper to Categorie 
	 * @param categorieWrapper
	 * @return
	 */
	public static Tax convertTaxWrapperToTax (TaxWrapper taxWrapper) {
		Tax tax = new Tax ();
		tax.setId(taxWrapper.getId());
		tax.setName(taxWrapper.getName());
		tax.setDescription(taxWrapper.getDescription());
		tax.setTax(taxWrapper.getTaxValue());
		tax.setCountry(taxWrapper.getCountry());
		tax.setStatus(taxWrapper.getStatus());
	    return tax;
	}
	
	/**
	 * convert List of ProductWrapper to Vector of ProductWrapper
	 * @param productWrapperList
	 * @return productList
	 */
	public static Vector <Product> convertProductWrapperListToProductList (List <ProductWrapper> productWrapperList ) {
		if (productWrapperList.size() == 0) return null;
		Vector <Product> productList = new Vector <Product>();
		for (int i = 0; i < productWrapperList.size(); i++) {
			ProductWrapper productWrapperItem = (ProductWrapper) productWrapperList.get(i);
			if (productWrapperItem == null) continue;
			Product item = convertProductWrapperToProduct(productWrapperItem);
			if (item == null) continue;
			productList.add(item);
		}
		return productList;
	}
	
	
	/***
	 * convert ProductWrapper to Product
	 * @param productWrapper
	 * @return Product
	 */
	public static Product convertProductWrapperToProduct (ProductWrapper productWrapper) {
		Product product = new Product ();
		product.setId(productWrapper.getId());
		String name = StringsUtil.replaceSpicialChars(productWrapper.getName()).trim();
		product.setProductName(name);
		product.setPLU(productWrapper.getPlu());
		product.setProductPrice(productWrapper.getPrice());
		
		/* calculate max Rabbat */
		int maxRabbat = 0;
		if (productWrapper.getHappyHourPrice() > 0) {
			float oneProcent = (float) (productWrapper.getPrice()/100);
			float priceDifferenz = productWrapper.getPrice() - productWrapper.getHappyHourPrice();
			if (oneProcent > 0) maxRabbat = (int)(priceDifferenz/oneProcent);
			if (maxRabbat < 0) maxRabbat = 0;
		}
		product.setMaxProductDiscount(maxRabbat);
		
		product.setProductTaxId(productWrapper.getTaxId());
		product.setProductTax(productWrapper.getTax());
		product.setCategorieId(productWrapper.getCategoryId());
		product.setProductColor(productWrapper.getProductColor());
		product.setProductSortIndex(productWrapper.getSortId());
		product.setProductConsisted(productWrapper.getProductConsisted());
		product.setFloatPrice(productWrapper.isHasVariablePrice());
		product.setWithSupplement(productWrapper.isWithSupplement());
		return product;
		
	}

	
	/**
	 * convert List of SupplementWrapper to Vector of ProductSupplement
	 * @param supplementWrapperList
	 * @return productSupplementList
	 */
	public static Vector <ProductSupplement> convertSupplementWrapperListToProductSupplementList (List <SupplementWrapper> supplementWrapperList ) {
		if (supplementWrapperList.size() == 0) return null;
		Vector <ProductSupplement> productSupplementList = new Vector <ProductSupplement>();
		for (int i = 0; i < supplementWrapperList.size(); i++) {
			SupplementWrapper supplementWrapperItem = (SupplementWrapper) supplementWrapperList.get(i);
			if (supplementWrapperItem == null) continue;
			ProductSupplement item = convertSupplementWrapperToProductSupplement(supplementWrapperItem);
			if (item == null) continue;
			productSupplementList.add(item);
		}
		return productSupplementList;
	}
	
	/**
	 * Convert SupplementWrapper to ProductSupplement
	 * @param supplementWrapper
	 * @return ProductSupplement
	 */
	public static ProductSupplement convertSupplementWrapperToProductSupplement (SupplementWrapper supplementWrapper) {
		ProductSupplement supplement = new ProductSupplement ();
		supplement.setId(supplementWrapper.getId());
		supplement.setProductSupplementCategorieId(supplementWrapper.getCategoryId());
		supplement.setProductSupplementColor(supplementWrapper.getColor());
		supplement.setProductSupplementConsisted(supplementWrapper.isConsisted());
		supplement.setProductSupplementModeId(supplementWrapper.getModeId());
		String name = StringsUtil.replaceSpicialChars(supplementWrapper.getName()).trim();
		supplement.setProductSupplementName(name);
		supplement.setProductSupplementProductId(supplementWrapper.getProductId());
		supplement.setProductSupplementSortId(supplementWrapper.getSortId());
		return supplement;
	}
	
	/**
	 * convert List of AdditionWrapper to Vector of ProductAddition
	 * @param additionWrapperList
	 * @return productAdditionList
	 */
	public static Vector <ProductAddition> convertAdditionWrapperListToProductAdditionList (List <AdditionWrapper> additionWrapperList ) {
		if (additionWrapperList.size() == 0) return null;
		Vector <ProductAddition> productAdditionList = new Vector <ProductAddition>();
		for (int i = 0; i < additionWrapperList.size(); i++) {
			AdditionWrapper additionWrapperItem = (AdditionWrapper) additionWrapperList.get(i);
			if (additionWrapperItem == null) continue;
			ProductAddition item = convertAdditionWrapperToProductAddition(additionWrapperItem);
			if (item == null) continue;
			productAdditionList.add(item);
		}
		return productAdditionList;
	}
	
	/***
	 * convert AdditionWrapper to ProductAddition
	 * @param AdditionWrapper
	 * @return ProductAddition
	 */
	public static ProductAddition convertAdditionWrapperToProductAddition (AdditionWrapper additionWrapper) {
		ProductAddition productAddition = new ProductAddition ();
		productAddition.setId(additionWrapper.getId());
		String name = StringsUtil.replaceSpicialChars(additionWrapper.getName()).trim();
		productAddition.setProductAdditionName(name);
		productAddition.setProductAdditionPrice1(additionWrapper.getPrice1());
		productAddition.setProductAdditionPrice2(additionWrapper.getPrice2());
		productAddition.setProductAdditionPrice3(additionWrapper.getPrice3());
		productAddition.setProductAdditionPrice4(additionWrapper.getPrice4());
		productAddition.setProductAdditionColor (additionWrapper.getColor());
		productAddition.setProductAdditionSortID(additionWrapper.getSortId());
		productAddition.setProductAdditionConsisted(additionWrapper.isConsisted());
		productAddition.setProductAdditionMode(additionWrapper.getMode());
		
		productAddition.setProductSelectedAdditionPrice(additionWrapper.getPrice());
		productAddition.setProductSelectedAdditionExtra(additionWrapper.isWith());
		productAddition.setProductSelectedAdditionWithout(additionWrapper.isWithout());
		
		return productAddition;
	}

	
	/**
	 * convert Vector  of ProductAddition to List of AdditionWrapper
	 * @param productAdditionsListList
	 * @return AdditionWrapperList
	 */
	public static List <AdditionWrapper> convertProductAdditionListToAdditionWrapperList (Vector <ProductAddition> productAdditionsList ) {
		if (productAdditionsList.size() == 0) return null;
		Vector <AdditionWrapper> additionWrapperList = new Vector <AdditionWrapper>();
		for (int i = 0; i < productAdditionsList.size(); i++) {
			ProductAddition productAdditionItem = (ProductAddition) productAdditionsList.get(i);
			if (productAdditionItem == null) continue;
			AdditionWrapper item = convertProductAdditionToAdditionWraper(productAdditionItem);
			if (item == null) continue;
			additionWrapperList.add(item);
		}
		return additionWrapperList;
	}
	
	/***
	 * convert ProductAddition to AdditionWrapper
	 * @param ProductAddition
	 * @return AdditionWrapper
	 */
	public static AdditionWrapper convertProductAdditionToAdditionWraper (ProductAddition addition) {
		AdditionWrapper additionWraper = new AdditionWrapper ();
		additionWraper.setId(addition.getId());
		String name = StringsUtil.replaceSpicialChars(addition.getProductAdditionName()).trim();
		additionWraper.setName(name);
		additionWraper.setPrice1(addition.getProductAdditionPrice1());
		additionWraper.setPrice2(addition.getProductAdditionPrice2());
		additionWraper.setPrice3(addition.getProductAdditionPrice3());
		additionWraper.setPrice4(addition.getProductAdditionPrice4());
		additionWraper.setColor (addition.getProductAdditionColor());
		additionWraper.setSortId(addition.getProductAdditionSortID());
		additionWraper.setConsisted(addition.isProductAdditionConsisted());
		additionWraper.setMode(addition.getProductAdditionMode());
		additionWraper.setPrice(addition.getProductSelectedAdditionPrice());
		additionWraper.setWith(addition.isProductSelectedAdditionExtra());
		additionWraper.setWithout(addition.isProductSelectedAdditionWithout());
		
		return additionWraper;
	}
	
	
	/***
	 * convert Product to ProductWrapper
	 * @param product
	 * @return ProductWrapper
	 */
	public static ProductWrapper convertProductToProductWrapper (Product product) {
		ProductWrapper productWrapper = new ProductWrapper ();
		productWrapper.setId(product.getId());
		productWrapper.setName(product.getProductName());
		productWrapper.setPlu(product.getPLU());
		productWrapper.setPrice(product.getProductPrice());
		productWrapper.setMaxDiscount(product.getMaxProductDiscount());
		productWrapper.setTaxId(product.getProductTaxId());
		productWrapper.setTax(product.getProductTax());
		productWrapper.setCategoryId(product.getCategorieId());
		productWrapper.setProductColor(product.getProductColor());
		productWrapper.setSortId(product.getProductSortIndex());
		productWrapper.setProductConsisted(product.getProductConsisted());
		productWrapper.setHasVariablePrice(product.isFloatPrice());
		return productWrapper;
	}
	
	
	
	/***
	 * Convert List of PrinterDriverWrapper to Vector of  PrinterDriver
	 * @param printerDriverWrapperList
	 * @return Vector <PrinterDriver>
	 */
	public static Vector <PrinterDriver> convertPrinterDriverWrapperListToPrinterDriverList (List <PrinterDriverWrapper> printerDriverWrapperList ) {
		if (printerDriverWrapperList.size() == 0) return null;
		Vector <PrinterDriver> printerDriverList = new Vector <PrinterDriver>();
		for (int i = 0; i < printerDriverWrapperList.size(); i++) {
			PrinterDriverWrapper printerDriverWrapperItem = (PrinterDriverWrapper) printerDriverWrapperList.get(i);
			if (printerDriverWrapperItem == null) continue;
			PrinterDriver item = convertPrinterDriverWrapperToPrinterDriver(printerDriverWrapperItem);
			if (item == null) continue;
			printerDriverList.add(item);
		}
		return printerDriverList;
	}
	
	/**
	 * Convert PrinterDriverWrapper to PrinterDriver
	 * @param printerDriverWrapper
	 * @return PrinterDriver
	 */
	public static PrinterDriver convertPrinterDriverWrapperToPrinterDriver (PrinterDriverWrapper printerDriverWrapper) {
		PrinterDriver printerDriver = new PrinterDriver();
		printerDriver.setPrinterId(printerDriverWrapper.getId());
		printerDriver.setPrinterWindowsName(printerDriverWrapper.getWinHandle()); 
		printerDriver.setPrinterName(printerDriverWrapper.getName());
		printerDriver.setPrinterServerIP(printerDriverWrapper.getIpAdress());
		printerDriver.setPrinterPort(printerDriverWrapper.getPort());
		printerDriver.setPrinterCharCountProLine(printerDriverWrapper.getLineCharCount());
		printerDriver.setPrinterLineSpacing(printerDriverWrapper.getLineSpacing());
		printerDriver.setUseESCPOS(printerDriverWrapper.isUseStandartCommands());
		
		/* Commands values */
		printerDriver.setTextAlignLeftValue(printerDriverWrapper.getAlignLeft());
		printerDriver.setTextAlignCenterValue(printerDriverWrapper.getAlignCenter());
		printerDriver.setTextAlignRightValue(printerDriverWrapper.getAlignRight());
		printerDriver.setPrintNVImageNormalValue(printerDriverWrapper.getPrintImageNormal());
		printerDriver.setPrintNVImageDoubleWidthValue(printerDriverWrapper.getPrintImageDoubleWidth());
		printerDriver.setPrintNVImageDoubleHeightValue(printerDriverWrapper.getPrintImageDoubleHeight());
		printerDriver.setPrintNVImageQuadrupleValue(printerDriverWrapper.getPrintImageQuadruple());
		
		/* Commands */
		printerDriver.setLineFeedCommand(printerDriverWrapper.getLineFeedCommand());
		printerDriver.setInitPrinterCommand(printerDriverWrapper.getInitPrinterCommand());
		printerDriver.setCutParerCommand(printerDriverWrapper.getCutPaperCommand());
		printerDriver.setOpenCashBoxCommand(printerDriverWrapper.getOpenCashDrawerCommand());   
		printerDriver.setSetPrintModeCommand(printerDriverWrapper.getSetPrintModeCommand());
		printerDriver.setSetCharsetCommand(printerDriverWrapper.getSetCharsetCommand());
		printerDriver.setSetTextAlignCommand(printerDriverWrapper.getSetTextAlignCommand());
		printerDriver.setSetDefaultLineSpacingCommand(printerDriverWrapper.getSetDefaultLineSpacingCommand());
		printerDriver.setSetDefaultLineSpacingCommand(printerDriverWrapper.getSetDefaultLineSpacingCommand());
		printerDriver.setPrintNVImageCommand(printerDriverWrapper.getPrintNvImageCommand());
		return printerDriver;
	}
	
	
	/***
	 * Convert List of BarcodeFormatWrapper to Vector of  BarcodeFormat
	 * @param BarcodeFormatWrapper
	 * @return Vector <BarcodeFormatBarcodeFormat>
	 */
	public static Vector <BarcodeFormat> convertBarcodeFormatsWrapperListToBarcodeFormatList (List <BarcodeFormatWrapper> barcodeFormatsWrapperList ) {
		if (barcodeFormatsWrapperList.size() == 0) return null;
		Vector <BarcodeFormat> barcodeFormatList = new Vector <BarcodeFormat>();
		for (int i = 0; i < barcodeFormatsWrapperList.size(); i++) {
			BarcodeFormatWrapper barcodeFormatWrapperItem = barcodeFormatsWrapperList.get(i);
			if (barcodeFormatWrapperItem == null) continue;
			BarcodeFormat item = convertBarcodeFormatWrapperToBarcodeFormat(barcodeFormatWrapperItem);
			if (item == null) continue;
			barcodeFormatList.add(item);
		}
		return barcodeFormatList;
	}
	
	/**
	 * convert BarcodeFormatWrapper to BarcodeFormat
	 * @param barcodeFormatWrapper
	 * @return BarcodeFormat
	 */
	public static BarcodeFormat convertBarcodeFormatWrapperToBarcodeFormat (BarcodeFormatWrapper barcodeFormatWrapper) {
		BarcodeFormat barcodeFormat = new BarcodeFormat();
		barcodeFormat.setId(barcodeFormatWrapper.getId());
		barcodeFormat.setBarcodeFormatName(barcodeFormatWrapper.getBarcodeFormatName());
		barcodeFormat.setBarcodeFormatPrefix(barcodeFormatWrapper.getBarcodeFormatPrefix());
		barcodeFormat.setBarcodeFormatLength(barcodeFormatWrapper.getBarcodeFormatLength());
		barcodeFormat.setBarcodeFormatTaxID(barcodeFormatWrapper.getBarcodeFormatTaxId());
		barcodeFormat.setBarcodeFormatTax(barcodeFormatWrapper.getBarcodeFormatTax());
		return barcodeFormat;
	}
	
	
	/***
	 * Convert List of BarcodeFormatFieldsWrapper to Vector of  BarcodeFormatField
	 * @param barcodeFormatFieldsWrapperList
	 * @return Vector <BarcodeFormatField>
	 */
	public static Vector <BarcodeFormatField> convertBarcodeFormatFieldsWrapperListToBarcodeFormatFieldList (List <BarcodeFormatFieldsWrapper> barcodeFormatFieldsWrapperList ) {
		if (barcodeFormatFieldsWrapperList.size() == 0) return null;
		Vector <BarcodeFormatField> barcodeFormatFieldList = new Vector <BarcodeFormatField>();
		for (int i = 0; i < barcodeFormatFieldsWrapperList.size(); i++) {
			BarcodeFormatFieldsWrapper barcodeFormatFieldsWrapperItem = barcodeFormatFieldsWrapperList.get(i);
			if (barcodeFormatFieldsWrapperItem == null) continue;
			BarcodeFormatField item = convertBarcodeFormatFieldWrapperToBarcodeFormatField(barcodeFormatFieldsWrapperItem);
			if (item == null) continue;
			barcodeFormatFieldList.add(item);
		}
		return barcodeFormatFieldList;
	}
	
	/**
	 * convert BarcodeFormatFieldsWrapper to BarcodeFormatField
	 * @param barcodeFormatFieldWrapper
	 * @return BarcodeFormatField
	 */
	public static BarcodeFormatField convertBarcodeFormatFieldWrapperToBarcodeFormatField (BarcodeFormatFieldsWrapper barcodeFormatFieldWrapper) {
		BarcodeFormatField barcodeFormatField = new BarcodeFormatField();
		barcodeFormatField.setId(barcodeFormatFieldWrapper.getId());
		barcodeFormatField.setBarcodeFormatID(barcodeFormatFieldWrapper.getBarcodeFormatId());
		barcodeFormatField.setBarcodeFormatFieldTyp(barcodeFormatFieldWrapper.getBarcodeFormatFieldTyp());
		barcodeFormatField.setBarcodeFormatFieldStart(barcodeFormatFieldWrapper.getBarcodeFormatFieldStart());
		barcodeFormatField.setBarcodeFormatFieldStop(barcodeFormatFieldWrapper.getBarcodeFormatFieldStop());
		return barcodeFormatField;
	}
	
	
	
	/**
	 * Convert List <CompositeOrderWrapper> to Vector <CompositeOrderItem>
	 * @param compositeOrderWrapperList
	 * @return Vector <CompositeOrderItem>
	 */
	public static Vector <CompositeOrderItem> convertCompositeOrderWrapperListToCompositeOrderItemList (List <CompositeOrderWrapper> compositeOrderWrapperList ) {
		if (compositeOrderWrapperList.size() == 0) return null;
		Vector <CompositeOrderItem> compositeOrderItemList = new Vector <CompositeOrderItem>();
		for (int i = 0; i < compositeOrderWrapperList.size(); i++) {
			CompositeOrderWrapper compositeOrderWrapperItem = (CompositeOrderWrapper) compositeOrderWrapperList.get(i);
			if (compositeOrderWrapperItem == null) continue;
			CompositeOrderItem item = convertCompositeOrderWrapperToCompositeOrderItem(compositeOrderWrapperItem);
			if (item == null) continue;
			compositeOrderItemList.add(item);
		}
		return compositeOrderItemList;
	}	
	
	/**
	 * Convert CompositeOrderWrapper to CompositeOrderItem
	 * @param compositeOrderWrapper
	 * @return CompositeOrderItem
	 */
	public static CompositeOrderItem convertCompositeOrderWrapperToCompositeOrderItem (CompositeOrderWrapper compositeOrderWrapper) {
		CompositeOrderItem item = new CompositeOrderItem();
	    item.setId(compositeOrderWrapper.getId());
	    String itemIdName = StringsUtil.replaceSpicialChars(compositeOrderWrapper.getItemIdName());
	    item.setItemIdName(itemIdName);
	    item.setSessionId(compositeOrderWrapper.getTableId());
	    item.setSessionName(compositeOrderWrapper.getTableName());
	    item.setUserId(compositeOrderWrapper.getUserId());
	    item.setUserName(compositeOrderWrapper.getUserName());
	    item.setProductId(compositeOrderWrapper.getProductId());
	    item.setProductPLU(compositeOrderWrapper.getPlu());
	    String productName = StringsUtil.replaceSpicialChars(compositeOrderWrapper.getProductName());
	    item.setProductName(productName);
	    item.setProductCount(compositeOrderWrapper.getProductCount());
	    item.setProductPrice(compositeOrderWrapper.getProductPrice());
	    item.setProductDiscount(compositeOrderWrapper.getProductDiscount());
	    item.setProductTax(compositeOrderWrapper.getProductTax());
	    Date createDate = DateUtils.getDateFromTimeStamp(compositeOrderWrapper.getDate()); 
	    item.setDate(createDate);
	    item.setProductCategorieId(compositeOrderWrapper.getCategoryId());
	    item.setPrintSaldo(compositeOrderWrapper.isSaldo());
	    item.setCustomerNumber(compositeOrderWrapper.getCustomerNumber());
	    item.setCustomerDiscount(compositeOrderWrapper.getCustomerDiscount());
		item.setComment(compositeOrderWrapper.getComment());
		item.setProductSupplementName(compositeOrderWrapper.getProductSupplementName());
		/*additions */
		item.setProductAdditions(compositeOrderWrapper.getProductAdditionsString());
		return item;
	}

	
	
	/**
	 * Convert CompositeOrderItem to CompositeOrderWrapper
	 * @param compositeOrderItem
	 * @return CompositeOrderWrapper
	 */
	public static CompositeOrderWrapper convertCompositeOrderItemToCompositeOrderWrapper (CompositeOrderItem compositeOrderItem) {
		CompositeOrderWrapper item = new CompositeOrderWrapper();
	    item.setId(compositeOrderItem.getId());
	    item.setItemIdName(compositeOrderItem.getItemIdName());
	    item.setOrderIdName(compositeOrderItem.getItemIdName());
	    item.setTableId(compositeOrderItem.getSessionId());
	    item.setTableName(compositeOrderItem.getSessionName());
	    item.setUserId(compositeOrderItem.getUserId());
	    item.setUserName(compositeOrderItem.getUserName());
	    item.setProductId(compositeOrderItem.getProductId());
	    item.setPlu(compositeOrderItem.getProductPLU());
	    item.setProductName(compositeOrderItem.getProductName());
	    item.setProductCount(compositeOrderItem.getProductCount());
	    item.setProductPrice(compositeOrderItem.getProductPrice());
	    item.setProductDiscount(compositeOrderItem.getProductDiscount());
	    item.setProductTax(compositeOrderItem.getProductTax());
	    item.setDate(compositeOrderItem.getDate().getTime());
	    item.setCategoryId(compositeOrderItem.getProductCategorieId());
	    item.setSaldo(compositeOrderItem.isPrintSaldo());
	    item.setCustomerNumber(compositeOrderItem.getCustomerNumber());
	    item.setCustomerDiscount(compositeOrderItem.getCustomerDiscount());
		item.setComment(compositeOrderItem.getComment());
		item.setProductSupplementName(compositeOrderItem.getProductSupplementName());
		item.setStatus(compositeOrderItem.STATUS_NORMAL);
		/*additions */
		try {
			item.setProductAdditionsString(compositeOrderItem.getProductAdditions());
			Vector <ProductAddition> productAdditionList = ProductAdditionsModul.convertCSVToProductAdditionsVector(compositeOrderItem.getProductAdditions());
			List <AdditionWrapper> additionWraperList = convertProductAdditionListToAdditionWrapperList(productAdditionList);
			item.setProductAdditionsList(additionWraperList);
		} catch (Exception e) {}
		
		return item;
	}
	
	/**
	 * Convert CompositeOrderItem to ReturnedOrderItemWrapper
	 * @param compositeOrderItem
	 * @return ReturnedOrderItemWrapper
	 */
	public static ReturnedOrderItemWrapper convertCompositeOrderItemToReturnedOrderItemWrapper (CompositeOrderItem compositeOrderItem, int strornedUserID, String strornedUserName, String stornoGrund) {
		ReturnedOrderItemWrapper item = new ReturnedOrderItemWrapper();
	    item.setId(compositeOrderItem.getId());
		item.setItemIdName(compositeOrderItem.getItemIdName());
	    item.setLevelDetailId(compositeOrderItem.getSessionId());
	    item.setLevelDetailName(compositeOrderItem.getSessionName());
	    item.setUserId(compositeOrderItem.getUserId());
	    item.setUserName(compositeOrderItem.getUserName());
	    /* stornierende user */
	    item.setReversalUserId(strornedUserID);
	    item.setReversalUserName(strornedUserName);
	    item.setProductId(compositeOrderItem.getProductId());
	    item.setProductPlu(compositeOrderItem.getProductPLU());
	    item.setProductName(compositeOrderItem.getProductName());
	    item.setProductCount(compositeOrderItem.getProductCount());
	    item.setProductPrice(compositeOrderItem.getProductPrice());
	    item.setProductDiscount(compositeOrderItem.getProductDiscount());
	    item.setProductTax(compositeOrderItem.getProductTax());
	    item.setDate(compositeOrderItem.getDate().getTime());
	    item.setReversalDate(DateUtils.getNowTimeStamp());
	    item.setProductCategorieId(compositeOrderItem.getProductCategorieId());
	    if (compositeOrderItem.getProductDiscount() > 0) item.setIsDiscounted(true);
	    item.setIsHappyHour(false);
	    item.setProductAdditions(compositeOrderItem.getProductAdditions());
	    item.setProductSupplementName(compositeOrderItem.getProductSupplementName());
	    item.setComment(compositeOrderItem.getComment());
	    item.setReversalComment(stornoGrund);
	    item.setSeat(0);
	    item.setCourse(0);
	    item.setIsInstantReversal(true);
	    if (compositeOrderItem.isPrintSaldo()) item.setIsInstantReversal(false);
		return item;
	}
	
	/***
	 * Convert SoldProduct to CompositeOrderWrapper
	 * @param soldProduct
	 * @return CompositeOrderWrapper
	 */
	public static CompositeOrderWrapper convertSoldProductItemToCompositeOrderWrapper (SoldProduct soldProduct) {
		CompositeOrderWrapper item = new CompositeOrderWrapper();
	    item.setId(0);
	    item.setItemIdName(soldProduct.getOrderIdName());
	    item.setOrderIdName(soldProduct.getOrderIdName());
	    //item.setTableId();
	    //item.setTableName();
	    item.setUserId(soldProduct.getUserId());
	    item.setUserName(soldProduct.getUserName());
	    item.setProductId(soldProduct.getProductId());
	    item.setPlu(soldProduct.getProductPLU());
	    item.setProductName(soldProduct.getProductName());
	    item.setProductCount(soldProduct.getProductCount());
	    item.setProductPrice(soldProduct.getProductPrice());
	    item.setProductDiscount(soldProduct.getProductDiscount());
	    item.setProductTax(soldProduct.getProductTax());
	    item.setDate(soldProduct.getDate().getTime());
	    item.setCategoryId(soldProduct.getProductCategorieId());
	    item.setSaldo(true);
	    //item.setCustomerNumber();
	    //item.setCustomerDiscount();
		item.setComment(soldProduct.getProductSupplementName());
		return item;
	}

	/**
	 * make compositeOrderWrapperList from SoldProducts Vector List 
	 * @param soldProduct
	 * @return
	 */
	public static List <CompositeOrderWrapper> convertSoldProductListToCompositeOrderWrapperList (Vector <SoldProduct> soldProductList, int tableID, String tableName) {
		List <CompositeOrderWrapper> compositeOrderWrapperList = new Vector <CompositeOrderWrapper>();
		for (int i = 0; i < soldProductList.size(); i++) {
			SoldProduct soldItem = soldProductList.get(i);
			if (soldItem == null) continue;
			CompositeOrderWrapper compositeOrderWrapper =  RESTWrapperBeansConverter.convertSoldProductItemToCompositeOrderWrapper(soldItem);
			if (compositeOrderWrapper == null) continue;
			compositeOrderWrapper.setTableId(tableID);
			compositeOrderWrapper.setTableName(tableName);
			compositeOrderWrapperList.add(compositeOrderWrapper);	
		}
		return compositeOrderWrapperList;
	}
	
	/**
	 * Convert Vector <SoldProduct> to List <SoldProductWrapper>
	 * @param soldProductList
	 * @return List <SoldProductWrapper>
	 */
	public static List <SoldProductWrapper> convertSoldProductListToSoldProductWrapperList (Vector <SoldProduct> soldProductList) {
		List <SoldProductWrapper> soldProductWrapperList = new Vector <SoldProductWrapper>();
		for (int i = 0; i < soldProductList.size(); i++) {
			SoldProduct soldItem = soldProductList.get(i);
			if (soldItem == null) continue;
			SoldProductWrapper soldProductWrapper =  RESTWrapperBeansConverter.convertSoldProductToSoldProductWrapper(soldItem);
			if (soldProductWrapper == null) continue;
			soldProductWrapperList.add(soldProductWrapper);
		}
		return soldProductWrapperList;
	}

	
	/**
	 * convert SoldProduct to SoldProductWrapper
	 * @param soldProduct
	 * @return
	 */
	public static SoldProductWrapper convertSoldProductToSoldProductWrapper (SoldProduct soldProduct) {
		SoldProductWrapper item = new SoldProductWrapper();
		item.setId(soldProduct.getId());
		item.setPaymentOrderNumber(soldProduct.getPaymentOrderNumber());
		item.setReceiptNumber(soldProduct.getBonNumber());
		item.setUserId(soldProduct.getUserId());
		item.setUserName(soldProduct.getUserName());
		item.setProductId(soldProduct.getProductId());
		item.setPlu(soldProduct.getProductPLU());
		item.setName(soldProduct.getProductName());
		item.setCount(soldProduct.getProductCount());
		item.setPrice(soldProduct.getProductPrice());     
		item.setDiscount(soldProduct.getProductDiscount());
		item.setTaxId(soldProduct.getProductTaxId());
		item.setTax(soldProduct.getProductTax());
		item.setStaticTax(soldProduct.isStaticTax());
		item.setDate(soldProduct.getDate().getTime());
		item.setCategoryId(soldProduct.getProductCategorieId());
		item.setCategoryName(soldProduct.getProductCategorieName());
		item.setMode(soldProduct.getMode());
		item.setCustomerDiscount(soldProduct.getCustomerDiscount());
		item.setAdditions(soldProduct.getProductAdditions());
		item.setAdditionsPrice(0);
		item.setAdditions(soldProduct.getProductAdditions());
		item.setSupplementName(soldProduct.getProductSupplementName());
		item.setDeviceId(soldProduct.getDeviceId());
		item.setServerReadSuccessful(true);
		item.setIsProcessed(0);
		item.setProcessedTime(0);
		return item;
	}
	
	
	/**
	 * Convert List <SoldProductWrapper> to Vector <SoldProduct>
	 * @param soldProductWrapperList
	 * @return Vector <SoldProduct>
	 */
	public static Vector <SoldProduct> convertSoldProductWrapperListToSoldProductList (List <SoldProductWrapper> soldProductWrapperList) {
		Vector <SoldProduct> soldProductList = new Vector <SoldProduct>();
		for (int i = 0; i < soldProductWrapperList.size(); i++) {
			SoldProductWrapper soldItemWrapper = soldProductWrapperList.get(i);
			if (soldItemWrapper == null) continue;
			SoldProduct soldProduct =  RESTWrapperBeansConverter.convertSoldProductWrapperToSoldProduct(soldItemWrapper);
			if (soldProduct == null) continue;
			soldProductList.add(soldProduct);
		}
		return soldProductList;
	}

	
	/**
	 * convert SoldProductWrapper to SoldProduct 
	 * @param soldProduct
	 * @return SoldProduct
	 */
	public static SoldProduct convertSoldProductWrapperToSoldProduct (SoldProductWrapper soldProductWrapper) {
		SoldProduct item = new SoldProduct();
		item.setId(soldProductWrapper.getId());
		item.setPaymentOrderNumber(soldProductWrapper.getPaymentOrderNumber());
		item.setBonNumber(soldProductWrapper.getReceiptNumber());
		item.setUserId(soldProductWrapper.getUserId());
		item.setUserName(soldProductWrapper.getUserName());
		item.setProductId(soldProductWrapper.getProductId());
		item.setProductPLU(soldProductWrapper.getPlu());
		item.setProductName(soldProductWrapper.getName());
		item.setProductCount(soldProductWrapper.getCount());
		item.setProductPrice(soldProductWrapper.getPrice());     
		item.setProductDiscount(soldProductWrapper.getDiscount());
		item.setProductTaxId(soldProductWrapper.getTaxId());
		item.setProductTax(soldProductWrapper.getTax());
		item.setStaticTax(soldProductWrapper.isStaticTax());
		item.setDate(new Date (soldProductWrapper.getDate()));
		item.setProductCategorieId(soldProductWrapper.getCategoryId());
		item.setProductCategorieName(soldProductWrapper.getCategoryName());
		item.setMode(soldProductWrapper.getMode());
		item.setCustomerDiscount(soldProductWrapper.getCustomerDiscount());
		item.setProductAdditions(soldProductWrapper.getAdditions());
		item.setProductSupplementName(soldProductWrapper.getSupplementName());
		item.setDeviceId(soldProductWrapper.getDeviceId());
		return item;
	}
	
	
	
	/***
	 * convert ConfigWrapper to Vector <SettingsParameter>
	 * @param config
	 * @return Vector <SettingsParameter>
	 */
	public static Vector <SettingsParameter> convertConfigWrapperToSettingsParameterList(ConfigWrapper config) {
		Vector <SettingsParameter> settingsList = new Vector <SettingsParameter>();
		settingsList.add(new SettingsParameter ("SHOW_PRODUCT_CONSISTED",config.showProductConsisted));
		settingsList.add(new SettingsParameter ("CHECK_PRODUCT_CONSISTED",config.checkProductConsisted));
		settingsList.add(new SettingsParameter ("NO_ADD_PRODUCTS_BY_CONSISTED_MINUS",config.noAddProductsByConsistedMinus));
		settingsList.add(new SettingsParameter ("USE_DRINKMONEY_FUNCTION",config.useDrinkmoneyFunction));
		settingsList.add(new SettingsParameter ("USE_CONDENCE_BON_PRODUCTS_FUNCTION",config.useCondenceBonProductsFunction));
		settingsList.add(new SettingsParameter ("USE_CONDENCE_SALDO_PRODUCTS_FUNCTION",config.useCondenceSaldoProductsFunction));
		settingsList.add(new SettingsParameter ("USE_BON_STORNO_FUNCTION",config.useBonStornoFunction));
		settingsList.add(new SettingsParameter ("SALDO_WITHOUT_PRINT_FUNCTION",config.saldoWithoutPrintFunction));
		settingsList.add(new SettingsParameter ("ONLY_FIRSRT_USER_CAN_SERVE",config.onlyFirsrtUserCanServe));
		settingsList.add(new SettingsParameter ("USE_SAVE_SALDO_ON_SERVER",config.useSaveSaldoOnServer));
		settingsList.add(new SettingsParameter ("PRINT_SALDO_SINGLE_PRODUCTS",config.printSaldoSingleProducts));
		settingsList.add(new SettingsParameter ("CURRENCY_NAME",config.currencyName));
		settingsList.add(new SettingsParameter ("OTHER_PRODUCTS_START_TEXT",config.otherProductsStartText));
		settingsList.add(new SettingsParameter ("PRODUCT_TAX_ID_DEFAULT_VALUE",config.productTaxIdDefaultValue));
		settingsList.add(new SettingsParameter ("PRODUCT_TAX_DEFAULT_VALUE",config.productTaxDefaultValue));
		settingsList.add(new SettingsParameter ("DEFAULT_PRINTER_ID",config.defaultPrinterId));
		settingsList.add(new SettingsParameter ("DEFAULT_PRINTER_ID",config.defaultPrintServerPort));
		settingsList.add(new SettingsParameter ("DEFAULT_PRINT_SERVER_IP",config.defaultPrintServerIp));
		settingsList.add(new SettingsParameter ("USE_FTP_SERVER_BACKUP",config.useFtpServerBackup));
		settingsList.add(new SettingsParameter ("FTP_SERVER_IP",config.ftpServerIp));
		settingsList.add(new SettingsParameter ("FTP_SERVER_PORT",config.ftpServerPort));
		settingsList.add(new SettingsParameter ("FTP_SERVER_DIR",config.ftpServerDir));
		settingsList.add(new SettingsParameter ("FTP_SERVER_USERNAME",config.ftpServerUsername));
		settingsList.add(new SettingsParameter ("FTP_SERVER_USERPASSWOconfig.RD",config.ftpServerUserpassword));
		settingsList.add(new SettingsParameter ("CUSTOMER_DISPLAY_SERVER_IP",config.customerDisplayServerIp));
		settingsList.add(new SettingsParameter ("CUSTOMER_DISPLAY_SERVER_PORT",config.customerDisplayServerPort));
		settingsList.add(new SettingsParameter ("CUSTOMER_DISPLAY_CHARS_PRO_LINE",config.customerDisplayCharsProLine));
		settingsList.add(new SettingsParameter ("CUSTOMER_DISPLAY_LEFT_CHARS_COUNT",config.customerDisplayLeftCharsCount));
		settingsList.add(new SettingsParameter ("CUSTOMER_DISPLAY_START_MESSAGE",config.customerDisplayStartMessage));
		settingsList.add(new SettingsParameter ("DATABASE_VERSION",config.databaseVersion));
		settingsList.add(new SettingsParameter ("CUSTOMER_DISPLAY_HANDLE",config.customerDisplayHandle));
		settingsList.add(new SettingsParameter ("USE_SECONDERY_DISPLAY",config.useSeconderyDisplay));
		settingsList.add(new SettingsParameter ("SECONDARY_DISPLAY_PATH ",config.secondaryDisplayPath));
		settingsList.add(new SettingsParameter ("GAME_DIRECTORY",config.gameDirectory));
		settingsList.add(new SettingsParameter ("ENABLE_GAME",config.enableGame));
		settingsList.add(new SettingsParameter ("GOTO_TABLES_AFTER_SALDO",config.afterOrderGotoLevelDetails));
		settingsList.add(new SettingsParameter ("GOTO_LEVELS_AFTER_SALDO",config.afterOrderGotoLevels));
		settingsList.add(new SettingsParameter ("LOGOUT_AFTER_SALDO",config.afterOrderLogout));
		settingsList.add(new SettingsParameter ("GOTO_TABLES_AFTER_BON",config.afterReceiptGotoLevelDetails));
		settingsList.add(new SettingsParameter ("GOTO_LEVELS_AFTER_BON",config.afterReceiptGotoLevels));
		settingsList.add(new SettingsParameter ("LOGOUT_AFTER_BON",config.afterReceiptLogout));
		settingsList.add(new SettingsParameter ("FIRMS_NAME",config.companyName));
		settingsList.add(new SettingsParameter ("FIRMS_STREET",config.companyAdress));
		settingsList.add(new SettingsParameter ("FIRMS_CITY",config.companyCity));
		settingsList.add(new SettingsParameter ("FIRMS_EMAIL",config.companyEmail));
		settingsList.add(new SettingsParameter ("FIRMS_PERSON_NAME",config.companyOwner));
		settingsList.add(new SettingsParameter ("FIRMS_TELEFON",config.companyPhone));
		settingsList.add(new SettingsParameter ("FIRMS_TAX_NUMBER",config.companyTaxId));
		settingsList.add(new SettingsParameter ("FIRMS_ZIP",config.companyZip));
		settingsList.add(new SettingsParameter ("PRINT_COMPANY_NAME",config.printCompanyName));
		settingsList.add(new SettingsParameter ("PRINT_COMPANY_STREET",config.printCompanyStreet));
		settingsList.add(new SettingsParameter ("PRINT_COMPANY_PHONE",config.printCompanyPhone));
		settingsList.add(new SettingsParameter ("PRINT_COMPANY_OWNER",config.printCompanyOwner));
		settingsList.add(new SettingsParameter ("PRINT_COMPANY_ZIP",config.printCompanyZip));
		settingsList.add(new SettingsParameter ("PRINT_COMPANY_TURNOVER_TAX_ID",config.printCompanyTurnoverTaxId));
		settingsList.add(new SettingsParameter ("PRINT_COMPANY_EMAIL",config.printCompanyEmail));
		settingsList.add(new SettingsParameter ("PRINT_COMPANY_CITY",config.printCompanyCity));
		settingsList.add(new SettingsParameter ("CASH_DRAWER_PORT",config.cashDrawerPort));
		settingsList.add(new SettingsParameter ("EC_TERMINAL_PORT",config.ecTerminalPort));
		settingsList.add(new SettingsParameter ("KDS_PRINTER_HANDLE",config.kdsPrinterHandle));
		settingsList.add(new SettingsParameter ("USE_ZVT_TERMINAL",config.useZvtTerminal));
		settingsList.add(new SettingsParameter ("SOFTWARE_EDITION",config.softwareEdition));
		settingsList.add(new SettingsParameter ("BON_FOOTER",config.receiptFooter));
		settingsList.add(new SettingsParameter ("USE_RKSV",config.useRksvModule));
		settingsList.add(new SettingsParameter ("RKSV_CONFIGURED",config.rksvConfigured));
		settingsList.add(new SettingsParameter ("USE_RKSV",config.isActive));
		settingsList.add(new SettingsParameter ("RKSV_AES_KEY",config.aesKey));
		settingsList.add(new SettingsParameter ("RKSV_AES_CHECKSUM",config.aesChecksum));
		settingsList.add(new SettingsParameter ("RKSV_CIN",config.cin));
		settingsList.add(new SettingsParameter ("RKSV_CERTIFICATE",config.certificate));
		settingsList.add(new SettingsParameter ("RKSV_CERTIFICATE_PUBLIC_KEY",config.certificatePublicKey));
		settingsList.add(new SettingsParameter ("RKSV_CERTIFICATE_SERIAL_NUMBER",config.certificateSerialNumber));
		settingsList.add(new SettingsParameter ("RKSV_LAST_RECEIPT_ID",config.lastReceiptId));
		settingsList.add(new SettingsParameter ("RKSV_PIN",config.pin));
		settingsList.add(new SettingsParameter ("RKSV_RECEIPT_PREFIX",config.receiptPrefix));
		settingsList.add(new SettingsParameter ("RKSV_AWAITING_COLLECTION",config.awaitingCollectionReceipt));
		settingsList.add(new SettingsParameter ("RKSV_FIRST_DAMAGED_RECEIPT",config.firstDamagedReceiptSignature));
		settingsList.add(new SettingsParameter ("RKSV_LAST_DAMAGED_RECEIPT",config.lastDamagedRecieptSignature));
		settingsList.add(new SettingsParameter ("RKSV_UID",config.uid));
		settingsList.add(new SettingsParameter ("RKSV_CASHBOX_ID",config.registerName));
		settingsList.add(new SettingsParameter ("RKSV_LAST_SIGNATURE",config.lastSignature));
		settingsList.add(new SettingsParameter ("RKSV_START_RECEIPT_DONE",config.startReceiptPrinted));
		settingsList.add(new SettingsParameter ("DEVICE_DAMAGED_START_DATE",config.deviceDamagedStartDate));
		settingsList.add(new SettingsParameter ("RKSV_TRAINING_MODE",config.rksvTrainingMode));
		settingsList.add(new SettingsParameter ("USE_INSIKA",config.useInsika));
		settingsList.add(new SettingsParameter ("DEMO_STAMP",config.demoStamp));
		settingsList.add(new SettingsParameter ("USE_MAGNETIC_KEY",config.useMagneticKey));
		settingsList.add(new SettingsParameter ("INSTANT_SALE",config.instantSale));
		settingsList.add(new SettingsParameter ("USE_TCP_CUSTOMER_DISPLAY",config.useTcpCustomerDisplay));
		settingsList.add(new SettingsParameter ("TCP_CUSTOMER_DISPLAY_HOST",config.tcpCustomerDisplayHost));
		settingsList.add(new SettingsParameter ("TCP_CUSTOMER_DISPLAY_PORT",config.tcpCustomerDisplayPort));
		settingsList.add(new SettingsParameter ("USE_TCP_CAMERA_CONTROLLER",config.useTcpCammeraController));
		settingsList.add(new SettingsParameter ("TCP_CAMERA_CONTROLLER_HOST",config.tcpCameraControllerHost));
		settingsList.add(new SettingsParameter ("TCP_CAMERA_CONTROLLER_PORT",config.tcpCameraControllerPort));
		settingsList.add(new SettingsParameter ("USE_TCP_ORDER_STATUS_DISPLAY",config.useTcpOrderStatusDisplay));
		settingsList.add(new SettingsParameter ("TCP_ORDER_STATUS_DISPLAY_HOST",config.tcpOrderStatusDisplayHost));
		settingsList.add(new SettingsParameter ("TCP_ORDER_STATUS_DISPLAY_PORT",config.tcpOrderStatusDisplayPort));
		settingsList.add(new SettingsParameter ("DISABLE_LOOKUP_RECEIPT",config.disableLookupReceipt));
		settingsList.add(new SettingsParameter ("DISABLE_REPRINT_RECEIPT",config.disableReprintReceipt));
		settingsList.add(new SettingsParameter ("DISABLE_REPRINT_BUSINESS_RECEIPT",config.disableReprintBusinessReceipt));
		settingsList.add(new SettingsParameter ("DISABLE_CASH_OUTPUT",config.disableCashOutput));
		settingsList.add(new SettingsParameter ("DISABLE_CASH_INPUT",config.disableCashInput));
		settingsList.add(new SettingsParameter ("DISABLE_SELECT_CUSTOMER",config.disableSelectCustomer));
		settingsList.add(new SettingsParameter ("DISABLE_DRAWER_PULL",config.disableDrawerPull));
		settingsList.add(new SettingsParameter ("DISABLE_USER_REPORT",config.disableUserReport));
		settingsList.add(new SettingsParameter ("DISABLE_SPLIT_PRODUCT_COUNT",config.disableSplitProductCount));
		settingsList.add(new SettingsParameter ("DISABLE_UNPAID_LEVEL_DETAILS",config.disableUnpaidLevelDetails));
		settingsList.add(new SettingsParameter ("DISABLE_OPEN_CASH_DRAWER",config.disableOpenCashDrawer));
		settingsList.add(new SettingsParameter ("DISABLE_EC_PAYMENT",config.disableEcPayment));
		settingsList.add(new SettingsParameter ("DISABLE_TAKE_AWAY_KEY",config.disableTakeAwayKey));
		settingsList.add(new SettingsParameter ("DISABLE_NO_RECEIPT_KEY",config.disableNoReceiptKey));
		settingsList.add(new SettingsParameter ("DISABLE_TEMP_RECEIPT",config.disableTempReceipt));
		settingsList.add(new SettingsParameter ("DISABLE_DELIVERY_ADDRESS",config.disableDeliveryAddress));
		settingsList.add(new SettingsParameter ("DISABLE_DELIVERY_NOTE",config.disableDeliveryNote));
		settingsList.add(new SettingsParameter ("DISABLE_BUSINESS_RECEIPT_IN_INVOICE",config.disableBusinessReceiptInInvoice));
		settingsList.add(new SettingsParameter ("DISABLE_AREA_CHANGE",config.disableAreaChange));
		return settingsList;
	}
	
	/***
	 * Convert List of CustomerWrapper to Vector of  Customer
	 * @param CustomerWrapperList
	 * @return Vector <Customer>
	 */
	public static Vector <Customer> convertCustomerWrapperListToCustomerList (List <CustomerWrapper> customerWrapperList ) {
		if (customerWrapperList.size() == 0) return null;
		Vector <Customer> printerDriverList = new Vector <Customer>();
		for (int i = 0; i < customerWrapperList.size(); i++) {
			CustomerWrapper customerWrapperItem = (CustomerWrapper) customerWrapperList.get(i);
			if (customerWrapperItem == null) continue;
			Customer item = convertCustomerWrapperToCustomer(customerWrapperItem);
			if (item == null) continue;
			printerDriverList.add(item);
		}
		return printerDriverList;
	}
	
	/**
	 * Convert CustomerWrapper to Customer
	 * @param printerDriverWrapper
	 * @return Customer
	 */
	public static Customer convertCustomerWrapperToCustomer (CustomerWrapper customerWrapper) {
		Customer customer = new Customer ();
		customer.setId(customerWrapper.getCustomerId());
		String convertedString = StringsUtil.replaceSpicialChars(customerWrapper.getCustomerNumber());
		customer.setCustomerNumber(convertedString);
		convertedString = StringsUtil.replaceSpicialChars(customerWrapper.getCustomerCompany());
		customer.setCustomerFirma(convertedString);
		convertedString = StringsUtil.replaceSpicialChars(customerWrapper.getCustomerName());
		customer.setCustomerName(convertedString);
		convertedString = StringsUtil.replaceSpicialChars(customerWrapper.getCustomerAddress());
		customer.setCustomerStreet(convertedString);
		customer.setCustomerZipCode(customerWrapper.getCustomerZip());
		convertedString = StringsUtil.replaceSpicialChars(customerWrapper.getCustomerCity());
		customer.setCustomerCity(convertedString);
		convertedString = StringsUtil.replaceSpicialChars(customerWrapper.getCustomerCard());
		customer.setCustomerCart(convertedString);
		customer.setCustomerDiscount(customerWrapper.getCustomerDiscount());
		convertedString = StringsUtil.replaceSpicialChars(customerWrapper.getCustomerComment());
		customer.setCustomerComment(convertedString);
		Date birthDate = DateUtils.getDateFromTimeStamp(customerWrapper.getCustomerBirthday());
		customer.setCustomerBirthDay(birthDate);
		Date createDate = DateUtils.getDateFromTimeStamp(customerWrapper.getCustomerCreationDate());
		customer.setCustomerDate(createDate);
		return customer;
	}
	
	
	
	/***
	 * Convert List of PaidOrdersWrapper to Vector of PaidOrders
	 * @param PaidOrdersWrapperList
	 * @return Vector <PaidOrders>
	 */
	public static Vector <PaidOrders> convertPaidOrdersWrapperListToPaidOrdersList (List <PaidOrdersWrapper> paidOrdersWrapperList ) {
		if (paidOrdersWrapperList.size() == 0) return null;
		Vector <PaidOrders> paidOrdersList = new Vector <PaidOrders>();
		for (int i = 0; i < paidOrdersWrapperList.size(); i++) {
			PaidOrdersWrapper paidOrdersWrapperItem = (PaidOrdersWrapper) paidOrdersWrapperList.get(i);
			if (paidOrdersWrapperItem == null) continue;
			PaidOrders item = convertPaidOrdersWrapperToPaidOrders(paidOrdersWrapperItem);
			if (item == null) continue;
			paidOrdersList.add(item);
		}
		return paidOrdersList;
	}
	
	/**
	 * Convert PaidOrdersWrapper to PaidOrders
	 * @param PaidOrdersWrapper
	 * @return PaidOrders
	 */
	public static PaidOrders convertPaidOrdersWrapperToPaidOrders (PaidOrdersWrapper paidOrdersWrapper) {
		PaidOrders paidOrders = new PaidOrders ();
		paidOrders.setId(paidOrdersWrapper.getId());
		paidOrders.setBonNumber(paidOrdersWrapper.getReceiptNumber());
		paidOrders.setPaymentOrdersNumber(paidOrdersWrapper.getPaymentOrdersNumber());
		paidOrders.setPaymentMode(paidOrdersWrapper.getPaymentMode());
		paidOrders.setTotalProductsCount(paidOrdersWrapper.getProductCount());
		paidOrders.setTableId(paidOrdersWrapper.getLevelDetailId());
		paidOrders.setTableName(paidOrdersWrapper.getLevelDetailText());
		paidOrders.setTableText(paidOrdersWrapper.getLevelDetailText());
		//private float discountSum;
		paidOrders.setCustomerDiscount(paidOrdersWrapper.getCustomerDiscount());
		paidOrders.setCustomerText(paidOrdersWrapper.getCustomerText());
		paidOrders.setCustomerNumber(paidOrdersWrapper.getCustomerNumber());
		paidOrders.setPersonalId(paidOrdersWrapper.getPersonnelId());
		paidOrders.setPersonalName(paidOrdersWrapper.getPersonnelName());
		Date date = new Date (paidOrdersWrapper.getDate());
		paidOrders.setDate(date);
		paidOrders.setSumm(paidOrdersWrapper.getSumm());
		paidOrders.setPaid(paidOrdersWrapper.isPaid());
		paidOrders.setCustomerShippingAdress(paidOrdersWrapper.getShippingAdress());
		paidOrders.setOrderMode(paidOrdersWrapper.getOrderMode());
		paidOrders.setGivenMoney(paidOrdersWrapper.getMoneyGiven());
		paidOrders.setDrinkMoney(paidOrdersWrapper.getTippingMoney());
		paidOrders.setBackMoney(paidOrdersWrapper.getReturnMoney());       
		paidOrders.setInputMoney(paidOrdersWrapper.getInputMoney());
		paidOrders.setOutputMoney(paidOrdersWrapper.getOutputMoney());
		paidOrders.setComment(paidOrdersWrapper.getComment());
		paidOrders.setDeviceId(paidOrdersWrapper.getDeviceId());
		paidOrders.setServerReadSuccesfull(true);
	    
	    //    private boolean isReversal;
	    //    public String receiptsSignature = "";
		return paidOrders;
	}
	
	/**
	 * Convert LastPaidOrderWrapper to PaidOrders
	 * @param LastPaidOrderWrapper
	 * @return PaidOrders
	 */
	public static PaidOrders convertLastPaidOrderWrapperToPaidOrders (LastPaidOrderWrapper lastPaidOrderWrapper) {
		PaidOrders paidOrders = new PaidOrders ();
		paidOrders.setId(lastPaidOrderWrapper.getId());
		paidOrders.setBonNumber(lastPaidOrderWrapper.getReceiptNumber());
		paidOrders.setPaymentOrdersNumber(lastPaidOrderWrapper.getPaymentOrdersNumber());
		paidOrders.setPaymentMode(lastPaidOrderWrapper.getPaymentMode());
		paidOrders.setTotalProductsCount(lastPaidOrderWrapper.getProductCount());
		paidOrders.setTableId(lastPaidOrderWrapper.getLevelDetailId());
		paidOrders.setTableName(lastPaidOrderWrapper.getLevelDetailText());
		paidOrders.setTableText(lastPaidOrderWrapper.getLevelDetailText());
		//private float discountSum;
		paidOrders.setCustomerDiscount(lastPaidOrderWrapper.getCustomerDiscount());
		paidOrders.setCustomerText(lastPaidOrderWrapper.getCustomerText());
		paidOrders.setCustomerNumber(lastPaidOrderWrapper.getCustomerNumber());
		paidOrders.setPersonalId(lastPaidOrderWrapper.getPersonnelId());
		paidOrders.setPersonalName(lastPaidOrderWrapper.getPersonnelName());
		Date date = new Date (lastPaidOrderWrapper.getDate());
		paidOrders.setDate(date);
		paidOrders.setSumm(lastPaidOrderWrapper.getSumm());
		paidOrders.setPaid(lastPaidOrderWrapper.isPaid());
		paidOrders.setCustomerShippingAdress(lastPaidOrderWrapper.getShippingAdress());
		paidOrders.setOrderMode(lastPaidOrderWrapper.getOrderMode());
		paidOrders.setGivenMoney(lastPaidOrderWrapper.getMoneyGiven());
		paidOrders.setDrinkMoney(lastPaidOrderWrapper.getTippingMoney());
		paidOrders.setBackMoney(lastPaidOrderWrapper.getReturnMoney());       
		paidOrders.setInputMoney(lastPaidOrderWrapper.getInputMoney());
		paidOrders.setOutputMoney(lastPaidOrderWrapper.getOutputMoney());
		paidOrders.setComment(lastPaidOrderWrapper.getComment());
		paidOrders.setDeviceId(lastPaidOrderWrapper.getDeviceId());
		paidOrders.setServerReadSuccesfull(true);
	    //    private boolean isReversal;
	    //    public String receiptsSignature = "";
		return paidOrders;
	}
	
	/***
	 * Convert PaidOrders to PaidOrdersWrapper
	 * @param paidOrders
	 * @return PaidOrdersWrapper
	 */
	public static PaidOrdersWrapper convertPaidOrdersToPaidOrdersWrapper (PaidOrders paidOrders) {
		PaidOrdersWrapper paidOrdersWrapper = new PaidOrdersWrapper ();
		paidOrdersWrapper.setId(paidOrders.getId());
		paidOrdersWrapper.setReceiptNumber(paidOrders.getBonNumber());
		paidOrdersWrapper.setPaymentOrdersNumber(paidOrders.getPaymentOrdersNumber());
		paidOrdersWrapper.setPaymentMode(paidOrders.getPaymentMode());
		paidOrdersWrapper.setProductCount(paidOrders.getTotalProductsCount());
		paidOrdersWrapper.setLevelDetailId(paidOrders.getTableId());
		paidOrdersWrapper.setLevelDetailText(paidOrders.getTableText());
		//private float discountSum;
		paidOrdersWrapper.setCustomerDiscount(paidOrders.getCustomerDiscount());
		paidOrdersWrapper.setCustomerText(paidOrders.getCustomerText());
		paidOrdersWrapper.setCustomerNumber(paidOrders.getCustomerNumber());
		paidOrdersWrapper.setPersonnelId(paidOrders.getPersonalId());
		paidOrdersWrapper.setPersonnelName(paidOrders.getPersonalName());
		long date = paidOrders.getDate().getTime();
		paidOrdersWrapper.setDate(date);
		paidOrdersWrapper.setSumm(paidOrders.getSumm());
		paidOrdersWrapper.setPaid(paidOrders.isPaid());
		paidOrdersWrapper.setShippingAdress(paidOrders.getCustomerShippingAdress());
		paidOrdersWrapper.setOrderMode(paidOrders.getOrderMode());
		paidOrdersWrapper.setMoneyGiven(paidOrders.getGivenMoney());
		paidOrdersWrapper.setTippingMoney(paidOrders.getDrinkMoney());
		paidOrdersWrapper.setReturnMoney(paidOrders.getBackMoney());       
		paidOrdersWrapper.setInputMoney(paidOrders.getInputMoney());
		paidOrdersWrapper.setOutputMoney(paidOrders.getOutputMoney());
		paidOrdersWrapper.setComment(paidOrders.getComment());
		paidOrdersWrapper.setDeviceId(paidOrders.getDeviceId());
		paidOrdersWrapper.setServerReadSuccessful(true);
	    //    private boolean isReversal;
	    //    public String receiptsSignature = "";
		return paidOrdersWrapper;
	}
	
	
}
