package de.blitzkassewinmac.rest.modul;

import java.util.List;
import java.util.logging.Level;

import com.google.gson.Gson;

import de.blitzkassewinmac.bean.Bon;
import de.blitzkassewinmac.bean.PaidOrders;
import de.blitzkassewinmac.converter.ProductOrderItemConverter;
import de.blitzkassewinmac.rest.bean.CompositeOrderWrapper;
import de.blitzkassewinmac.rest.bean.InputOutputReceiptWrapper;
import de.blitzkassewinmac.rest.bean.LevelDetailWrapper;
import de.blitzkassewinmac.rest.bean.PaidOrdersWrapper;
import de.blitzkassewinmac.rest.bean.PassWrapper;
import de.blitzkassewinmac.rest.bean.ReceiptWrapper;
import de.blitzkassewinmac.rest.bean.ReturnedOrderItemWrapper;
import de.blitzkassewinmac.rest.bean.SoldProductWrapper;
import de.blitzkassewinmac.rest.converter.RESTWrapperBeansConverter;
import de.blitzkassewinmac.util.DevicesUtil;
import de.blitzkassewinmac.util.HttpURLConnectionUtils;

public class RESTInteraktionModul {
	private static final String LOG_TAG = "RESTInteraktionModul";
	private static final boolean PRINT_LOG = false;
	
	/***
	 * Get session/login
	 * @param loggedUserPassword
	 * @param ipAdress
	 * @param ipPort
	 * @return
	 */
	public static String getUserRESTSession(String loggedUserPassword, String ipAdress, int ipPort) {
		if (loggedUserPassword == null) return null;
		
		/* make requrest and json string */
		PassWrapper requestObj =  new PassWrapper();
		requestObj.setPotzWord(loggedUserPassword);
		String jsonInString = (new Gson()).toJson(requestObj);
		
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/LoginPlebUser";
		String responseJsonInString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			responseJsonInString = responseJsonInString.replace("null", "");
			responseJsonInString = responseJsonInString.replace("\"", "");
		} catch (Exception e) {}
		return (responseJsonInString);
	}	
	
	
	
	/***
	 * Select aktiv Level
	 * @param aktiveLevel
	 * @param sessionID
	 * @param ipAdress
	 * @param ipPort
	 * @return
	 */
	public static String setRESTSessionsLevel(Level aktiveLevel, String sessionID, String ipAdress, int ipPort) {
		if (sessionID == null) return null;
		if (aktiveLevel == null) return null;
		
		/* make requrest and json string */
		Level requestObj =  aktiveLevel;
		String jsonInString = (new Gson()).toJson(requestObj);
		
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/SelectLevel?me=" + sessionID;
		String responseJsonInString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			responseJsonInString = responseJsonInString.replace("null", "");
			responseJsonInString = responseJsonInString.replace("\"", "");
		} catch (Exception e) {}
		return (responseJsonInString);
	}

	/***
	 * Select aktive LevelDetail (Table)
	 * @param aktiveLevelDetail
	 * @param sessionID
	 * @param ipAdress
	 * @param ipPort
	 * @return
	 */
	public static String setRESTSessionsLevelDetail(LevelDetailWrapper aktiveLevelDetail, String sessionID, String ipAdress, int ipPort) {
		if (sessionID == null) return null;
		if (aktiveLevelDetail == null) return null;
		
		/* make requrest and json string */
		LevelDetailWrapper requestObj =  aktiveLevelDetail;
		String jsonInString = (new Gson()).toJson(requestObj);
		
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/SelectLevelDetail?me=" + sessionID;
		String responseJsonInString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			responseJsonInString = responseJsonInString.replace("null", "");
			responseJsonInString = responseJsonInString.replace("\"", "");
		} catch (Exception e) {}
		return (responseJsonInString);
	}
	
	/**
	 * save CompositeOrder
	 * @param compositeOrderWrapper
	 * @param sessionID
	 * @param ipAdress
	 * @param ipPort
	 * @return responseJsonInString
	 */
	public static String saveCompositeOrderREST(CompositeOrderWrapper compositeOrderWrapper, String sessionID, String ipAdress, int ipPort) {
		if (sessionID == null) return null;
		if (compositeOrderWrapper == null) return null;
		
		/* make requrest and json string */
		CompositeOrderWrapper requestObj =  compositeOrderWrapper;
		String jsonInString = (new Gson()).toJson(requestObj);
		
		/* send jsoon to server */
		String restServerURL = "http://" + ipAdress + ":" + ipPort + "/SaveCompositeOrder?me=" + sessionID;
		String responseJsonInString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(restServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			responseJsonInString = responseJsonInString.replace("null", "");
		} catch (Exception e) {}
		return (responseJsonInString);
	}
	
	/**
	 * Delete compositeOrderItem
	 * @param compositeOrderWrapper
	 * @param sessionID
	 * @param ipAdress
	 * @param ipPort
	 * @return responseJsonInString
	 */
	public static String deleteCompositeOrderREST(ReturnedOrderItemWrapper returnedOrderWrapper, String sessionID, String ipAdress, int ipPort) {
		if (sessionID == null) return null;
		if (returnedOrderWrapper == null) return null;
		
		/* make requrest and json string */
		ReturnedOrderItemWrapper requestObj =  returnedOrderWrapper;
		String jsonInString = (new Gson()).toJson(requestObj);
		
		/* send jsoon to server */
		String restServerURL = "http://" + ipAdress + ":" + ipPort + "/InsertCancellation?me=" + sessionID;
		String responseJsonInString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(restServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}

			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			responseJsonInString = responseJsonInString.replace("null", "");
		} catch (Exception e) {}
		return (responseJsonInString);
	}
	
	/***
	 * Print X-Abschlag on Server
	 * @param loggedUserPassword
	 * @param ipAdress
	 * @param ipPort
	 * @return
	 */
	public static String printRESTXPayment(String loggedUserPassword, String ipAdress, int ipPort) {
		String sessionID = getUserRESTSession(loggedUserPassword, ipAdress, ipPort);
		String returnValue = sendPrintRESTXPayment (sessionID, ipAdress, ipPort);
		return returnValue;
	}
	
	/***
	 * Make and Print X-Payment on Server for sessions user
	 * @param sessionID
	 * @param ipAdress
	 * @param ipPort
	 * @return 
	 */
	private static String sendPrintRESTXPayment(String sessionID, String ipAdress, int ipPort) {
		if (sessionID == null) return null;
		
		/* make requrest and json string */
		String jsonInString = "";
		
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/printUserReport?&local=true&me=" + sessionID;
		String responseString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_GET);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
			/* JSON to Java object, read it from a Json String. */
			responseString = httpURLConnection.getResponseContent();
			responseString = responseString.replace("null", "");
			responseString = responseString.replace("\"", "");
		} catch (Exception e) {}
		return (responseString);
	}
	
	/***
	 * Print Z-Abschlag on Server
	 * @param loggedUserPassword
	 * @param ipAdress
	 * @param ipPort
	 * @return
	 */
	public static String printRESTZPayment(String loggedUserPassword, String ipAdress, int ipPort) {
		String sessionID = getUserRESTSession(loggedUserPassword, ipAdress, ipPort);
		String returnValue = sendPrintRESTZPayment (sessionID, ipAdress, ipPort);
		return returnValue;
	}
	
	/***
	 * Make and Print Z-Payment on Server for sessions user
	 * @param sessionID
	 * @param ipAdress
	 * @param ipPort
	 * @return 
	 */
	private static String sendPrintRESTZPayment(String sessionID, String ipAdress, int ipPort) {
		if (sessionID == null) return null;
		
		/* make requrest and json string */
		String jsonInString = "";
		
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/executePull";
		String responseString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_GET);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
			/* JSON to Java object, read it from a Json String. */
			responseString = httpURLConnection.getResponseContent();
			responseString = responseString.replace("null", "");
			responseString = responseString.replace("\"", "");
		} catch (Exception e) {}
		return (responseString);
	}
	
	
	/***
	 * Save new Bon on Server
	 * @param bon
	 * @param sessionID
	 * @param ipAdress
	 * @param ipPort
	 * @return
	 */
	public static String sendBonREST(Bon bon, String sessionID, String ipAdress, int ipPort) {
		return sendBonREST(bon, sessionID, ipAdress, ipPort, true, false, false);
	}
	
	public static String sendBonREST(Bon bon, String sessionID, String ipAdress, int ipPort, boolean noPrintBonOnServer, boolean printAllowanceReceipt, boolean printShipmentReceipt) {
		if (sessionID == null) return null;
		if (bon == null) return null;
		
		/* make requrest and json string */
		ReceiptWrapper requestObj =  getReceiptWrapperFromBon(bon, noPrintBonOnServer, printAllowanceReceipt, printShipmentReceipt);
		String jsonInString = (new Gson()).toJson(requestObj);
		if (PRINT_LOG) System.out.println("ReceiptWrapper = " + jsonInString);
		
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/ExecuteReceipt?me=" + sessionID;
		String responseJsonInString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			responseJsonInString = responseJsonInString.replace("null", "");
			responseJsonInString = responseJsonInString.replace("\"", "");
		} catch (Exception e) {}
		return (responseJsonInString);
	}
		
	public static ReceiptWrapper getReceiptWrapperFromBon(Bon bon, boolean noPrintBonOnServer, boolean printAllowanceReceipt, boolean printShipmentReceipt) {
		ReceiptWrapper receiptWrapper = new ReceiptWrapper();
		/* make PaidOrdersWrapper */
		PaidOrders paidOrders = ProductOrderItemConverter.convertBonToPaidOrders(bon); 
		PaidOrdersWrapper paidOrdersWrapper = RESTWrapperBeansConverter.convertPaidOrdersToPaidOrdersWrapper(paidOrders); 
		
		/* make compositeOrderWrapperList from SoldProductsList */
		List <CompositeOrderWrapper> compositeOrderWrapperList = RESTWrapperBeansConverter.convertSoldProductListToCompositeOrderWrapperList (bon.getSoldProductsList(), bon.getTableId(), bon.getTableName());
		
		/* make SoldProductWrapperList from SoldProductsList */
		List <SoldProductWrapper> soldProductWrapperList = RESTWrapperBeansConverter.convertSoldProductListToSoldProductWrapperList(bon.getSoldProductsList());

		receiptWrapper.setOrder(paidOrdersWrapper);
		receiptWrapper.setOrderPrecursors(compositeOrderWrapperList);
		receiptWrapper.setOrderProducts(soldProductWrapperList);
		receiptWrapper.setNoPrint(noPrintBonOnServer);
		receiptWrapper.setAllowanceReceipt(printAllowanceReceipt);
		receiptWrapper.setShipmentReceipt(printShipmentReceipt);
		receiptWrapper.setShipmentAddress(bon.getCustomerShippingAdress());
		return receiptWrapper;
	}
	
	/***
	 * Send InputOutputReceipt on Server
	 * @param inputOutputWrapper
	 * @param ipAdress
	 * @param ipPort
	 * @return boolean
	 */
	public static boolean sendInputOutputReceiptREST(InputOutputReceiptWrapper inputOutputWrapper, String ipAdress, int ipPort) {
		if (inputOutputWrapper == null) return false;
		
		/* make requrest and json string */
		String jsonInString = (new Gson()).toJson(inputOutputWrapper);
		if (PRINT_LOG) System.out.println("InputOutputReceipt = " + jsonInString);
		
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/InputOutputReceipt";
		String responseJsonInString = "";
		boolean saveFlag = false; 
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			if (responseJsonInString != null) {
				responseJsonInString = responseJsonInString.replace("null", "");
				responseJsonInString = responseJsonInString.replace("\"", "");
				if (responseJsonInString.trim().toLowerCase().equals("true")) saveFlag = true;
			}
		} catch (Exception e) {}
		return (saveFlag);
	}


	/***
	 * Set Status fr Benutzer
	 * STATUS_NORMALL = 1;
	 * STATUS_LOGGED_USER = 3;
	 * @param sessionID
	 * @param newStatus
	 * @param ipAdress
	 * @param ipPort
	 * @return boolean
	 */
	public static boolean setUserStatusByIDREST(String sessionID, int newStatus, String ipAdress, int ipPort) {
				
		/* make requrest and json string */
		String jsonInString = "" + newStatus;
		if (PRINT_LOG) System.out.println("newStatus = " + jsonInString);
		
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/SetUserStatus?me=" + sessionID;
		String responseJsonInString = "";
		boolean saveFlag = false; 
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, jsonInString);
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_POST);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			if (responseJsonInString != null) {
				responseJsonInString = responseJsonInString.replace("null", "");
				responseJsonInString = responseJsonInString.replace("\"", "");
				if (responseJsonInString.trim().toLowerCase().equals("true")) saveFlag = true;
			}
		} catch (Exception e) {}
		return (saveFlag);
	}
	
}
