package de.blitzkassewinmac.rest.modul;

import java.io.StringReader;
import java.util.List;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.google.gson.stream.JsonReader;

import de.blitzkassewinmac.rest.bean.AdditionWrapper;
import de.blitzkassewinmac.rest.bean.AreaWrapper;
import de.blitzkassewinmac.rest.bean.BarcodeFormatFieldsWrapper;
import de.blitzkassewinmac.rest.bean.BarcodeFormatWrapper;
import de.blitzkassewinmac.rest.bean.CategorieWrapper;
import de.blitzkassewinmac.rest.bean.CompositeOrderWrapper;
import de.blitzkassewinmac.rest.bean.ConfigWrapper;
import de.blitzkassewinmac.rest.bean.CustomerWrapper;
import de.blitzkassewinmac.rest.bean.LastPaidOrderWrapper;
import de.blitzkassewinmac.rest.bean.LevelDetailWrapper;
import de.blitzkassewinmac.rest.bean.PaidOrdersWrapper;
import de.blitzkassewinmac.rest.bean.PrinterDriverWrapper;
import de.blitzkassewinmac.rest.bean.ProductWrapper;
import de.blitzkassewinmac.rest.bean.SupplementWrapper;
import de.blitzkassewinmac.rest.bean.TaxWrapper;
import de.blitzkassewinmac.rest.bean.UserWrapper;
import de.blitzkassewinmac.util.DevicesUtil;
import de.blitzkassewinmac.util.HttpURLConnectionUtils;

public class RESTModul {
	private static final String LOG_TAG = "RESTModul";
	private static final boolean PRINT_LOG = true;

	public static String getRESTObjectListString(String listCommand, String ipAdress, int ipPort) {
		/* send jsoon to server */
		String insikaServerURL = "http://" + ipAdress + ":" + ipPort + "/" + listCommand;
		String responseJsonInString = "";
		try {
			HttpURLConnectionUtils httpURLConnection = new HttpURLConnectionUtils(insikaServerURL, "");
			httpURLConnection.setRequestMethod(HttpURLConnectionUtils.REQUEST_METHOD_GET);
			httpURLConnection.setContentType("application/json");
			httpURLConnection.start();
			while (!httpURLConnection.isResponseContentFlag()) {
				DevicesUtil.Sleep(100);
			}
		
			/* JSON to Java object, read it from a Json String. */
			responseJsonInString = httpURLConnection.getResponseContent();
			/* delete start null */
			if (responseJsonInString.indexOf("null") < 4)  responseJsonInString = responseJsonInString.substring(4);
		} catch (Exception e) {}
		return (responseJsonInString);
	}
	
	
	/***
	 * Get all config entrys
	 * @param ipAdress
	 * @param ipPort
	 * @return ConfigWrapper
	 */
	public static ConfigWrapper getRESTConfigEntrys(String ipAdress, int ipPort) {
		ConfigWrapper returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("ConfigComplete", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<ConfigWrapper>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}	
	

	/***
	 * Get all areas
	 * @param ipAdress
	 * @param ipPort
	 * @return List of AreaWrapper
	 */
	public static List <AreaWrapper> getRESTAreasList(String ipAdress, int ipPort) {
		List <AreaWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getAreas", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<AreaWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}		
	
	/***
	 * Get all users
	 * @param ipAdress
	 * @param ipPort
	 * @return List of UserWrapper
	 */
	public static List <UserWrapper> getRESTUsersList(String ipAdress, int ipPort) {
		List <UserWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getUsers", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<UserWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}	
	
	/***
	 * Get List of LevelDetailWrapper
	 * @param ipAdress
	 * @param ipPort
	 * @return List of LevelDetailsWrappers
	 */
	public static List <LevelDetailWrapper> getRESTLevelDetailsList(String ipAdress, int ipPort) {
		List <LevelDetailWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getLevelDetails", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(jsonString, new TypeToken<List<LevelDetailWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}	
	
	/***
	 * get all categories
	 * @param ipAdress
	 * @param ipPort
	 * @return
	 */
	public static List <CategorieWrapper> getRESTCategoriesList(String ipAdress, int ipPort) {
		List <CategorieWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getCategories", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<CategorieWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}	
	
	
	/***
	 * get all products
	 * @param ipAdress
	 * @param ipPort
	 * @return List <ProductWrapper>
	 */
	public static List <ProductWrapper> getRESTProductsList(String ipAdress, int ipPort) {
		List <ProductWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getProducts", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<ProductWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}	
	

	/***
	 * get all additions
	 * @param ipAdress
	 * @param ipPort
	 * @return List <AdditionWrapper>
	 */
	public static List <AdditionWrapper> getRESTProductsAdditionsList(String ipAdress, int ipPort) {
		List <AdditionWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getAdditions", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<AdditionWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}
	
	/***
	 * get all supplements
	 * @param ipAdress
	 * @param ipPort
	 * @return List <SupplementWrapper>
	 */
	public static List <SupplementWrapper> getRESTProductsSupplementsList(String ipAdress, int ipPort) {
		List <SupplementWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getSupplements", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<SupplementWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}	

	
	/***
	 * get all taxes
	 * @param ipAdress
	 * @param ipPort
	 * @return List <TaxWrapper>
	 */
	public static List <TaxWrapper> getRESTTaxesList(String ipAdress, int ipPort) {
		List <TaxWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getTaxes", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<TaxWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}	
	
	/***
	 * get all printer drivers
	 * @param ipAdress
	 * @param ipPort
	 * @return List <PrinterDriverWrapper>
	 */
	public static List <PrinterDriverWrapper> getRESTPrinterDriversList(String ipAdress, int ipPort) {
		List <PrinterDriverWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getPrinterDrivers", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<PrinterDriverWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}
	
	/***
	 * get all Composite orders 
	 * @param ipAdress
	 * @param ipPort
	 * @return List <CompositeOrderWrapper>
	 */
	public static List <CompositeOrderWrapper> getRESTCompositeOrderList(String ipAdress, int ipPort) {
		List <CompositeOrderWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getAllCompositeOrders", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<CompositeOrderWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}	

	/***
	 * get all customer
	 * @param ipAdress
	 * @param ipPort
	 * @return List <CustomerWrapper
	 */
	public static List <CustomerWrapper> getRESTCustomerList(String ipAdress, int ipPort) {
		List <CustomerWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getCustomers", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<CustomerWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}		
	
	/***
	 * get all paid orders
	 * @param ipAdress
	 * @param ipPort
	 * @return List PaidOrdersWrapper
	 */
	public static List <PaidOrdersWrapper> getRESTPaidOrdersList(String ipAdress, int ipPort) {
		List <PaidOrdersWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getLookupReceipts", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<PaidOrdersWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}		
	
	/***
	 * get last paid orders
	 * @param ipAdress
	 * @param ipPort
	 * @return LastPaidOrdersWrapper
	 */
	public static LastPaidOrderWrapper getRESTLastPaidOrder(String ipAdress, int ipPort) {
		LastPaidOrderWrapper lastPaidOrder = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getLastReceipt", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			lastPaidOrder = gson.fromJson(reader, new TypeToken<LastPaidOrderWrapper>(){}.getType());
		} catch (Exception e) {}
		return lastPaidOrder;
	}		
	
	
	/**
	 * Get all barcode formats
	 * @param ipAdress
	 * @param ipPort
	 * @return List <BarcodeFormat>
	 */
	public static List <BarcodeFormatWrapper> getRESTBarcodeFormatsList(String ipAdress, int ipPort) {
		List <BarcodeFormatWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getBarcodeFormats", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<BarcodeFormatWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}
	
	/**
	 * Get all barcode format fields
	 * @param ipAdress
	 * @param ipPort
	 * @return List <BarcodeFormatFieldsWrapper>
	 */
	public static List <BarcodeFormatFieldsWrapper> getRESTBarcodeFormatFieldsList(String ipAdress, int ipPort) {
		List <BarcodeFormatFieldsWrapper> returnList = null;
		/* send jsoon to server */
		String jsonString = getRESTObjectListString ("getBarcodeFormatFields", ipAdress, ipPort);
		if (jsonString == null) return null;
	    JsonReader reader = new JsonReader(new StringReader(jsonString));
	    reader.setLenient(true);
		try {
			Gson gson = new Gson();
			returnList = gson.fromJson(reader, new TypeToken<List<BarcodeFormatFieldsWrapper>>(){}.getType());
		} catch (Exception e) {}
		return returnList;
	}		
	
}
